@@ -55,6 +55,10 @@ fi
 ( cd opt/kde/lib ; ln -sf libkdesu.so.4.2.0 libkdesu.so )
 ( cd opt/kde/lib ; rm -rf libkdeui.so )
 ( cd opt/kde/lib ; ln -sf libkdeui.so.4.2.0 libkdeui.so )
+( cd opt/kde/lib ; rm -rf libkdnssd.so.1 )
+( cd opt/kde/lib ; ln -sf libkdnssd.so.1.0.0 libkdnssd.so.1 )
+( cd opt/kde/lib ; rm -rf libkmdi2.so.1 )
+( cd opt/kde/lib ; ln -sf libkmdi2.so.1.0.0 libkmdi2.so.1 )
 ( cd opt/kde/lib ; rm -rf libkjava.so.1 )
 ( cd opt/kde/lib ; ln -sf libkjava.so.1.0.0 libkjava.so.1 )
 ( cd opt/kde/lib ; rm -rf libkspell2.so )
@@ -83,6 +87,8 @@ fi
 ( cd opt/kde/lib ; ln -sf libkmdi.so.1.0.0 libkmdi.so.1 )
 ( cd opt/kde/lib ; rm -rf libktexteditor.so )
 ( cd opt/kde/lib ; ln -sf libktexteditor.so.0.0.0 libktexteditor.so )
+( cd opt/kde/lib ; rm -rf libkmdi2.so )
+( cd opt/kde/lib ; ln -sf libkmdi2.so.1.0.0 libkmdi2.so )
 ( cd opt/kde/lib ; rm -rf libkabc_file.so.1 )
 ( cd opt/kde/lib ; ln -sf libkabc_file.so.1.0.0 libkabc_file.so.1 )
 ( cd opt/kde/lib ; rm -rf libvcard.so.0 )
@@ -107,6 +113,8 @@ fi
 ( cd opt/kde/lib ; ln -sf libkparts.so.2.1.0 libkparts.so.2 )
 ( cd opt/kde/lib ; rm -rf libkscript.so.0 )
 ( cd opt/kde/lib ; ln -sf libkscript.so.0.0.0 libkscript.so.0 )
+( cd opt/kde/lib ; rm -rf libkntlm.so.0 )
+( cd opt/kde/lib ; ln -sf libkntlm.so.0.0.0 libkntlm.so.0 )
 ( cd opt/kde/lib ; rm -rf libkresources.so )
 ( cd opt/kde/lib ; ln -sf libkresources.so.1.2.0 libkresources.so )
 ( cd opt/kde/lib ; rm -rf libvcard.so )
@@ -121,6 +129,8 @@ fi
 ( cd opt/kde/lib ; ln -sf libkmediaplayer.so.0.0.0 libkmediaplayer.so )
 ( cd opt/kde/lib ; rm -rf libkutils.so )
 ( cd opt/kde/lib ; ln -sf libkutils.so.1.2.0 libkutils.so )
+( cd opt/kde/lib ; rm -rf libkdnssd.so )
+( cd opt/kde/lib ; ln -sf libkdnssd.so.1.0.0 libkdnssd.so )
 ( cd opt/kde/lib ; rm -rf libkdefakes.so )
 ( cd opt/kde/lib ; ln -sf libkdefakes.so.4.2.0 libkdefakes.so )
 ( cd opt/kde/lib ; rm -rf libkmediaplayer.so.0 )
@@ -130,9 +140,11 @@ fi
 ( cd opt/kde/lib ; rm -rf libkabc_net.so.1 )
 ( cd opt/kde/lib ; ln -sf libkabc_net.so.1.0.0 libkabc_net.so.1 )
 ( cd opt/kde/lib ; rm -rf libkwalletclient.so.1 )
-( cd opt/kde/lib ; ln -sf libkwalletclient.so.1.0.0 libkwalletclient.so.1 )
+( cd opt/kde/lib ; ln -sf libkwalletclient.so.1.0.1 libkwalletclient.so.1 )
 ( cd opt/kde/lib ; rm -rf libkmdi.so )
 ( cd opt/kde/lib ; ln -sf libkmdi.so.1.0.0 libkmdi.so )
+( cd opt/kde/lib ; rm -rf libkntlm.so )
+( cd opt/kde/lib ; ln -sf libkntlm.so.0.0.0 libkntlm.so )
 ( cd opt/kde/lib ; rm -rf libkmid.so )
 ( cd opt/kde/lib ; ln -sf libkmid.so.0.0.95 libkmid.so )
 ( cd opt/kde/lib ; rm -rf libktexteditor.so.0 )
@@ -148,7 +160,7 @@ fi
 ( cd opt/kde/lib ; rm -rf libkabc.so.1 )
 ( cd opt/kde/lib ; ln -sf libkabc.so.1.2.0 libkabc.so.1 )
 ( cd opt/kde/lib ; rm -rf libkwalletclient.so )
-( cd opt/kde/lib ; ln -sf libkwalletclient.so.1.0.0 libkwalletclient.so )
+( cd opt/kde/lib ; ln -sf libkwalletclient.so.1.0.1 libkwalletclient.so )
 ( cd opt/kde/lib ; rm -rf libkhtml.so )
 ( cd opt/kde/lib ; ln -sf libkhtml.so.4.2.0 libkhtml.so )
 ( cd opt/kde/lib ; rm -rf libkio.so.4 )
