@@ -22,7 +22,7 @@
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
 */
-//$Id: kactionclasses.h,v 1.187 2004/01/05 11:05:55 bhards Exp $
+//$Id$
 
 #ifndef __kactionclasses_h__
 #define __kactionclasses_h__
@@ -58,13 +58,14 @@ class KPopupMenu;
 class KMainWindow;
 
 /**
+ *  @short Checkbox like action.
+ *
  *  Checkbox like action.
  *
  *  This action provides two states: checked or not.
  *
- *  @short Checkbox like action.
  */
-class KToggleAction : public KAction
+class KDEUI_EXPORT KToggleAction : public KAction
 {
     Q_OBJECT
     Q_PROPERTY( bool checked READ isChecked WRITE setChecked )
@@ -182,6 +183,22 @@ public:
      */
     virtual void setExclusiveGroup( const QString& name );
 
+    /**
+     * Defines the text (and icon, tooltip, whatsthis) that should be displayed
+     * instead of the normal text, when the action is checked.
+     * This feature replaces the checkmark that usually appears in front of the text, in menus.
+     * It is useful when the text is mainly a verb: e.g. "Show <foo>"
+     * should turn into "Hide <foo>" when activated.
+     *
+     * If hasIcon(), the icon is kept for the 'checked state', unless
+     * @p checkedItem defines an icon explicitely. Same thing for tooltip and whatsthis.
+     * @since 3.3
+     */
+    void setCheckedState( const KGuiItem& checkedItem );
+
+    /// Reimplemented for internal reasons
+    virtual QString toolTip() const;
+
 public slots:
     /**
      *  Sets the state of the action.
@@ -205,10 +222,12 @@ private:
 };
 
 /**
+ *  @short Radiobox like action.
+ *
  * An action that operates like a radio button. At any given time
  * only a single action from the group will be active.
  */
-class KRadioAction : public KToggleAction
+class KDEUI_EXPORT KRadioAction : public KToggleAction
 {
   Q_OBJECT
 public:
@@ -297,6 +316,8 @@ private:
 };
 
 /**
+ *  @short Action for selecting one of several items
+ *
  *  Action for selecting one of several items.
  *
  *  This action shows up a submenu with a list of items.
@@ -304,10 +325,8 @@ private:
  *  this item will automatically be checked,
  *  the formerly checked item becomes unchecked.
  *  There can be only one item checked at a time.
- *
- *  @short Action for selecting one of several items
  */
-class KSelectAction : public KAction
+class KDEUI_EXPORT KSelectAction : public KAction
 {
     Q_OBJECT
     Q_PROPERTY( int currentItem READ currentItem WRITE setCurrentItem )
@@ -549,7 +568,7 @@ private:
 /**
  * @deprecated Use KSelectAction instead.
  */
-class KDE_DEPRECATED KListAction : public KSelectAction
+class KDEUI_EXPORT_DEPRECATED KListAction : public KSelectAction
 {
     Q_OBJECT
 public:
@@ -655,15 +674,16 @@ private:
 };
 
 /**
+ *  @short Recent files action
+ *
  *  This class is an action to handle a recent files submenu.
  *  The best way to create the action is to use KStdAction::openRecent.
  *  Then you simply need to call loadEntries on startup, saveEntries
  *  on shutdown, addURL when your application loads/saves a file.
  *
  *  @author Michael Koch
- *  @short Recent files action
  */
-class KRecentFilesAction : public KListAction  // TODO public KSelectAction
+class KDEUI_EXPORT KRecentFilesAction : public KListAction  // TODO public KSelectAction
 {
   Q_OBJECT
   Q_PROPERTY( uint maxItems READ maxItems WRITE setMaxItems )
@@ -764,7 +784,7 @@ public:
   virtual ~KRecentFilesAction();
 
   virtual int plug( QWidget *widget, int index = -1 );
-  
+
   /**
    *  Returns the maximum of items in the recent files list.
    */
@@ -841,12 +861,12 @@ protected:
 
 private:
   void init();
-  
+
   class KRecentFilesActionPrivate;
   KRecentFilesActionPrivate *d;
 };
 
-class KFontAction : public KSelectAction
+class KDEUI_EXPORT KFontAction : public KSelectAction
 {
     Q_OBJECT
     Q_PROPERTY( QString font READ font WRITE setFont )
@@ -867,6 +887,16 @@ public:
                  const QObject* receiver, const char* slot, QObject* parent,
                  const char* name = 0 );
 
+// The ctors with fontListCriteria were added after 3.3-beta1.
+// This define is used in koffice. Remove when koffice has a dependency on kdelibs-3.3 or more.
+#define KFONTACTION_HAS_CRITERIA_ARG
+    KFontAction( uint fontListCriteria, const QString& text,
+                 const KShortcut& cut = KShortcut(), QObject* parent = 0,
+                 const char* name = 0 );
+    KFontAction( uint fontListCriteria, const QString& text, const QString& pix,
+                 const KShortcut& cut = KShortcut(),
+                 QObject* parent = 0, const char* name = 0 );
+
     KFontAction( QObject* parent = 0, const char* name = 0 );
     ~KFontAction();
 
@@ -886,7 +916,7 @@ private:
     KFontActionPrivate *d;
 };
 
-class KFontSizeAction : public KSelectAction
+class KDEUI_EXPORT KFontSizeAction : public KSelectAction
 {
     Q_OBJECT
     Q_PROPERTY( int fontSize READ fontSize WRITE setFontSize )
@@ -944,7 +974,7 @@ private:
  * If you want a submenu for selecting one tool among many (without icons), see KSelectAction.
  * See also setDelayed about the main action.
  */
-class KActionMenu : public KAction
+class KDEUI_EXPORT KActionMenu : public KAction
 {
   Q_OBJECT
   Q_PROPERTY( bool delayed READ delayed WRITE setDelayed )
@@ -1017,7 +1047,7 @@ private:
  * that has more detail in a toolbar than in a menu (e.g. tool chooser
  * with "Other" leading to a dialog...).
  */
-class KToolBarPopupAction : public KAction
+class KDEUI_EXPORT KToolBarPopupAction : public KAction
 {
   Q_OBJECT
   Q_PROPERTY( bool delayed READ delayed WRITE setDelayed )
@@ -1139,7 +1169,7 @@ private:
  * visibility has changed, whenever it changes.
  * @since 3.1
  */
-class KToggleToolBarAction : public KToggleAction
+class KDEUI_EXPORT KToggleToolBarAction : public KToggleAction
 {
     Q_OBJECT
 public:
@@ -1176,7 +1206,8 @@ private:
  * An action for switching between to/from full screen mode. Note that
  * QWidget::isFullScreen() may reflect the new or the old state
  * depending on how the action was triggered (by the application or
- * from the window manager). Rely on this action's state instead.
+ * from the window manager). Also don't try to track the window state
+ * yourself. Rely on this action's state (isChecked()) instead.
  *
  * Important: If you need to set/change the fullscreen state manually,
  * use the relevant QWidget function (showFullScreen etc.), do not
@@ -1184,7 +1215,7 @@ private:
  * still needs to explicitly set the window state though.
  * @since 3.2
  */
-class KToggleFullScreenAction : public KToggleAction
+class KDEUI_EXPORT KToggleFullScreenAction : public KToggleAction
 {
     Q_OBJECT
 public:
@@ -1228,7 +1259,7 @@ private:
  * An action that automatically embeds a widget into a
  * toolbar.
  */
-class KWidgetAction : public KAction
+class KDEUI_EXPORT KWidgetAction : public KAction
 {
     Q_OBJECT
 public:
@@ -1272,7 +1303,7 @@ private:
     KWidgetActionPrivate *d;
 };
 
-class KActionSeparator : public KAction
+class KDEUI_EXPORT KActionSeparator : public KAction
 {
     Q_OBJECT
 public:
@@ -1298,7 +1329,7 @@ private:
  *
  * @since 3.2
  */
-class KPasteTextAction: public KAction
+class KDEUI_EXPORT KPasteTextAction: public KAction
 {
     Q_OBJECT
 public:
@@ -1320,9 +1351,9 @@ public:
     KPasteTextAction( const QString& text, const QString& icon, const KShortcut& cut,
                   const QObject* receiver, const char* slot,
                   QObject* parent = 0, const char* name = 0 );
-    
+
     virtual ~KPasteTextAction();
-    
+
     /**
     * Controls the behavior of the clipboard history menu popup.
     *
@@ -1334,9 +1365,9 @@ public:
     *             Default value is true.
     */
     void setMixedMode(bool mode);
-    
+
     virtual int plug( QWidget *widget, int index = -1 );
-    
+
 protected slots:
     void menuAboutToShow();
     void menuItemActivated( int id);
