@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (C) 2000-2002 Thiago Macieira <thiagom@mail.com>
+ *  Copyright (C) 2000-2004 Thiago Macieira <thiago.macieira@kdemail.net>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -20,6 +20,10 @@
 #ifndef KEXTSOCK_H
 #define KEXTSOCK_H
 
+#include "kdelibs_export.h"
+
+#ifdef Q_OS_UNIX
+
 #include <sys/time.h>
 
 #include <qstring.h>
@@ -50,19 +54,19 @@ class KExtendedSocketPrivate;
 /**
  * The extended socket class.
  *
- * This class should be used instead of @ref KSocket whenever the user needs
+ * This class should be used instead of KSocket whenever the user needs
  * fine-grained control over the socket being created. Unlike KSocket, which
  * does everything at once, without much intervention, KExtendedSocket allows
  * intervention at every step of the process and the setting of parameters.
  *
  * This class allows for the creation of both server and client sockets. The
  * only difference is that the passiveSocket flag must be passed either to
- * the constructor or to @ref setSocketFlags(). If passiveSocket is used, the class will
- * enable functions @ref listen() and @ref accept() and related signals, and will
- * also disable @ref readBlock() and @ref writeBlock().
+ * the constructor or to setSocketFlags(). If passiveSocket is used, the class will
+ * enable functions listen() and accept() and related signals, and will
+ * also disable readBlock() and writeBlock().
  *
  * To create a Unix socket, one would pass flag unixSocket to the constructor
- * or @ref setSocketFlags(). The hostname and service/port can be set to whatever is
+ * or setSocketFlags(). The hostname and service/port can be set to whatever is
  * necessary. If no hostname is given, but a service/port is, the socket created
  * will be implementation dependant (usually in /tmp). In any other case, the
  * fields will be concatenated.
@@ -76,11 +80,15 @@ class KExtendedSocketPrivate;
  * to make sure only IPv4 and IPv6 sockets are selected, even if future implementations
  * support newer IP protocols, ipv4Socket | ipv6Socket is your guy.
  *
- * @author Thiago Macieira <thiagom@mail.com>
- * @version $Id: kextsock.h,v 1.30.2.2 2003/05/29 18:12:23 thiago Exp $
+ * @deprecated
+ *	This class is now deprecated. Please use the classes in @ref KNetwork for
+ *	new programs. In special, this class is replaced by @ref KNetwork::KStreamSocket
+ *	and @ref KNetwork::KServerSocket.
+ *
+ * @author Thiago Macieira <thiago.macieira@kdemail.net>
  * @short an extended socket
  */
-class KExtendedSocket: public KBufferedIO // public QObject, public QIODevice
+class KDECORE_EXPORT KExtendedSocket: public KBufferedIO // public QObject, public QIODevice
 {
   Q_OBJECT
 
@@ -153,6 +161,16 @@ public:
 
   /**
    * Creates a socket with the given hostname and port.
+   *
+   * If this is a connecting (active) socket, the hostname and port specify
+   * the remote address to which we will connect.
+   *
+   * If this is a listening (passive) socket, the hostname and port specify
+   * the address to listen on. In order to listen on every interface
+   * available on this node, set @p host to QString::null. To let the operating
+   * system select a port, set it to 0.
+   *
+   * @sa setAddress
    * @param host	the hostname
    * @param port	the port number
    * @param flags	flags
@@ -161,8 +179,18 @@ public:
 
   /**
    * Creates a socket with the given hostname and service.
+   *
+   * If this is a connecting (active) socket, the hostname and service specify
+   * the remote address to which we will connect.
+   *
+   * If this is a listening (passive) socket, the hostname and service specify
+   * the address to listen on. In order to listen on every interface
+   * available on this node, set @p host to QString::null. To let the operating
+   * system select a port, set the service to "0".
+   *
+   * @sa setAddress
    * @param host	the hostname
-   * @param serv	the service
+   * @param service	the service
    * @param flags	flags
    */
   KExtendedSocket(const QString& host, const QString& service, int flags = 0);
@@ -200,7 +228,7 @@ public:
   int systemError() const;
 
   /**
-   * Sets the given flags. 
+   * Sets the given flags.
    * @param flags	the flags to be set
    * @return the new flags status, or -1 if flags can no longer be set
    */
@@ -214,7 +242,15 @@ public:
   int socketFlags() const;
 
   /**
-   * Sets the hostname to the given value.
+   * Sets the hostname to the given value. 
+   *
+   * If this is a listening (passive) socket, the hostname is the host to which the socket
+   * will bind in order to listen. If you want to listen in every interface, set it
+   * to "*" or QString::null.
+   *
+   * If this is a connecting (active) socket, the hostname is the host to which we will try
+   * to connect.
+   *
    * @param host	the hostname
    * @return true on success, false on error
    */
@@ -234,10 +270,14 @@ public:
 
   /**
    * Sets the port/service.
+   *
+   * In the case of Unix-domain sockets, the port is the filename for the socket.
+   * If the name is not an absolute path, "/tmp/" will be prepended.
+   *
    * @param port	the port
    * @return true if successful, false on error (e.g. connection already established)
    */
-  bool setPort(const QString& service);
+  bool setPort(const QString& port);
 
   /**
    * Returns the port/service. If it is a port, the string contains a number.
@@ -247,6 +287,9 @@ public:
 
   /**
    * Sets the address where we will connect to.
+   *
+   * See @ref setHost and @ref setPort for information on the parameters.
+   *
    * @param host	the hostname
    * @param port	port number
    * @return true if successful, false on error (e.g. connection already established)
@@ -255,6 +298,9 @@ public:
 
   /**
    * Sets the address where we will connect to.
+   *
+   * See @ref setHost and @ref setPort for information on the parameters.
+   *
    * @param host	the hostname
    * @param serv	the service
    * @return true if successful, false on error (e.g. connection already established)
@@ -319,7 +365,7 @@ public:
    * Sets both host and service to which we will bind the socket. Will return
    * false if this is a passiveSocket.
    * @param host	the hostname
-   * @param serv	the service
+   * @param service	the service
    * @return true if successful, false on error (e.g. connection already established)
    */
   bool setBindAddress(const QString& host, const QString& service);
@@ -386,14 +432,14 @@ public:
   /**
    * Sets/unsets the v6-only flag for IPv6 sockets.
    *
-   * When an IPv6 socket is in use, communication with IPv4 sockets is 
+   * When an IPv6 socket is in use, communication with IPv4 sockets is
    * guaranteed by translating those IPv4 addresses into IPv6 ones
    * (specifically, the v4-mapped addresses). This flag allows that
-   * behaviour to be turned on and off.
+   * behavior to be turned on and off.
    *
    * Note that this does not have any effect on sockets that are not
    * IPv6 and the function will always return false in those cases.
-   * Also note that this flag defaults to off in order to accomodate
+   * Also note that this flag defaults to off in order to accommodate
    * existing applications.
    *
    * @param enable	if true, no IPv4 translation will be performed;
@@ -423,10 +469,6 @@ public:
    * buffer's to be discarded. Likewise, setting the size to a value less than
    * the current size will cause the buffer to be shrunk to the wanted value,
    * as if the data had been read.
-   *
-   * Note 2: The closed() signal will only be emitted for a connection closed
-   * by the remote end if we are doing input buffering. That happens because if we aren't
-   * reading from the connection, we don't know when it closed.
    * @param rsize	read buffer size
    * @param wsize	write buffer size
    * @return true on success, false if this is not possible in this state (e.g. connection
@@ -439,7 +481,7 @@ public:
    * @return the local socket address, can be 0 if the connection has not been established
    *         yet
    */
-  const KSocketAddress *localAddress();
+  const ::KSocketAddress *localAddress();
 
   /**
    * Returns the peer socket address. Use KExtendedSocket::resolve() to
@@ -447,7 +489,7 @@ public:
    * @return the peer address, can be 0 if the connection has not been established yet
    *         or the socket is passive
    */
-  const KSocketAddress *peerAddress();
+  const ::KSocketAddress *peerAddress();
 
   /**
    * Returns the file descriptor
@@ -475,14 +517,14 @@ public:
    * When the lookup is done, the lookupReady signal will be emitted.
    *
    * Note that, depending on the parameters for the lookup, this function might
-   * know the results without the need for blocking or queueing an
+   * know the results without the need for blocking or queuing an
    * asynchronous lookup. That means that the lookupReady signal might be
    * emitted by this function, so your code should be prepared for that.
    *
    * One such case is when noResolve flag is set.
-   * If this function is able to determine the results without queueing
+   * If this function is able to determine the results without queuing
    * and the lookup failed, this function will return -1.
-   * 
+   *
    * @return 0 on success or -1 on error. Note that
    * returning 0 means that either we are in the process of doing
    * lookup or that it has finished already.
@@ -496,7 +538,7 @@ public:
 
   /**
    * Place the socket in listen mode. The parameters are the same as for
-   * the system listen() call. 
+   * the system listen() call.
    * @param N		the queue length for pending connections
    * @return 0 on success, -1 on system error (errno
    *         available) and -2 if this is not a passiveSocket.
@@ -520,17 +562,17 @@ public:
   virtual int accept(KExtendedSocket *&sock);
 
   /**
-   * Attempts to connect to the remote host. 
+   * Attempts to connect to the remote host.
    * After successful connection (return value 0), the socket will be ready
    * for I/O operations. Note, however, that not all signals may be enabled
    * for emission by this socket:
-   * @li @ref readyRead and @ref readyWrite signals will be enabled only if
-   *    @ref enableRead or @ref enableWrite were called. You can still enable
+   * @li readyRead and readyWrite signals will be enabled only if
+   * enableRead or enableWrite were called. You can still enable
    *    them by calling those functions, of course.
    * @li #closed() will only be sent if we are indeed reading from the input
-   *    stream. That is, if this socket is buffering the input. See @ref setBufferSize
+   *    stream. That is, if this socket is buffering the input. See setBufferSize
    *
-   * Note that, in general, functions inherited/overriden from KBufferedIO will only
+   * Note that, in general, functions inherited/overridden from KBufferedIO will only
    * work on buffered sockets, like bytesAvailable and bytesToWrite.
    * @return    The return values are:
    * @li 0: success
@@ -546,13 +588,17 @@ public:
 
   /**
    * Starts an asynchronous connect. This works exactly the same as #connect,
-   * except that the connection result won't be returned. 
+   * except that the connection result won't be returned.
    *
    * Note that those signals might be emitted before this function returns, so your
    * code should be prepared for that condition.
-   * @return 0 on successful queueing of the connect or -1 on error. 
-   *         If this function returns 0, then the @ref connectionSuccess() or the 
-   *         @ref connectionFailed() signals will be emitted.
+   *
+   * You must call cancelAsyncConnect() before you delete the socket if you
+   * call this.  Otherwise you will have crashes.
+   *
+   * @return 0 on successful queuing of the connect or -1 on error.
+   *         If this function returns 0, then the connectionSuccess() or the
+   * connectionFailed() signals will be emitted.
    */
   virtual int startAsyncConnect();
 
@@ -562,7 +608,7 @@ public:
   virtual void cancelAsyncConnect();
 
   /**
-   * Implementation of @ref QIODevice::open() pure virtual function.
+   * Implementation of QIODevice::open() pure virtual function.
    * This depends on the target host address already being there.
    * If this is a passiveSocket, this is identical to call listen(); else, if
    * this is not a passiveSocket and no connection attempt is in progress, this
@@ -577,8 +623,8 @@ public:
    * Closes the socket. If we have data still in the write buffer yet to be
    * sent, the socket won't be closed right now. It'll be closed after we managed
    * to send everything out.
-   * If you want to close the socket now, you may want to call @ref flush() first,
-   * and then @ref closeNow().
+   * If you want to close the socket now, you may want to call flush() first,
+   * and then closeNow().
    */
   virtual void close();
 
@@ -616,12 +662,12 @@ public:
    * data as possible, but it will stop as soon as the kernel cannot receive
    * any more data, and would possibly block.
    *
-   * By repeatedly calling this function, the behaviour will be like that of
+   * By repeatedly calling this function, the behavior will be like that of
    * a blocking socket. Indeed, if this function is called with the kernel not
    * ready to receive data, it will block, unless this is a non-blocking socket.
    *
    * This function does not touch the read buffer. You can empty it by calling
-   * @ref readBlock() with a null destination buffer.
+   * readBlock() with a null destination buffer.
    */
   virtual void flush();
 
@@ -660,7 +706,7 @@ public:
    *
    * If the socket is not buffered, this function will simply call the underlying
    * read method. This function will block if the socket is not on non-blocking mode
-   * (see @ref setBlockingMode) and there is not enough data to be read in the
+   * (see setBlockingMode) and there is not enough data to be read in the
    * Operating System yet. If we are in non-blocking operation, the call will
    * fail in this case.
    *
@@ -722,7 +768,7 @@ public:
    *
    * @param data	where to store the data
    * @param maxlen	how many bytes to copy, at most
-   * @return the number of bytes copied. 0 does not mean end-of-file 
+   * @return the number of bytes copied. 0 does not mean end-of-file
    *         condition.
    */
   virtual int peekBlock(char *data, uint maxlen);
@@ -736,8 +782,8 @@ public:
   virtual int unreadBlock(const char *data, uint len);
 
   /**
-   * Returns the number of available bytes yet to be read via @ref readBlock
-   * and family of functions. 
+   * Returns the number of available bytes yet to be read via readBlock
+   * and family of functions.
    *
    * Note: as of now, this only works on input-buffered sockets. This will
    * change in the future
@@ -752,7 +798,7 @@ public:
    * read in the read buffer.
    *
    * @param msec	milliseconds to wait
-   * @return -1 in case of system error and -2 in case of invalid socket 
+   * @return -1 in case of system error and -2 in case of invalid socket
    *         state
    */
   virtual int waitForMore(int msec);
@@ -803,7 +849,7 @@ public:
 signals:
   /**
    * This signal is emitted whenever an asynchronous lookup process is done.
-   * The parameter @p count tells 
+   * The parameter @p count tells
    * @param count the number of results
    */
   void lookupFinished(int count);
@@ -877,13 +923,14 @@ public:
    * That is, tries to resolve the raw form of the socket address into a textual
    * representation.
    *
-   * @param sockaddr	the socket address
+   * @param sock	the socket address
+   * @param len         the length of the socket address
    * @param host	where the hostname will be written
    * @param port	where the service-port will be written
    * @param flags	the same flags as getnameinfo()
    * @returns 0 on success, nonzero otherwise.
    */
-  static int resolve(sockaddr* sock, ksocklen_t len, QString& host, QString& port, int flags = 0);
+  static int resolve(sockaddr* sock, ksocklen_t len, QString& host, QString& port, int flags = 0) KDE_DEPRECATED;
 
   /**
    * Performs resolution on the given socket address.
@@ -891,33 +938,35 @@ public:
    * That is, tries to resolve the raw form of the socket address into a textual
    * representation.
    *
-   * @param sockaddr	the socket address
+   * @param sock	the socket address
    * @param host	where the hostname will be written
    * @param port	where the service-port will be written
    * @param flags	the same flags as getnameinfo()
    * @returns 0 on success, nonzero otherwise.
    */
-  static int resolve(KSocketAddress* sock, QString& host, QString& port, int flags = 0);
+  static int resolve(::KSocketAddress* sock, QString& host, QString& port, int flags = 0) KDE_DEPRECATED;
 
-  /**
+  /** @deprecated
+   * This function is now deprecated. Please use @ref KNetwork::KResolver::resolve.
+   *
    * Performs lookup on the given hostname/port combination and returns a list
    * of matching addresses.
-   * The error code can be transformed into string by @ref KExtendedSocket::strError()
+   * The error code can be transformed into string by KExtendedSocket::strError()
    * with code of IO_LookupError.
    *
-   * IMPORTANT: the result values of the @ref QPtrList must be deleted after use. So,
-   * if you don't copy the @ref KAddressInfo objects, the best way to assure that
+   * IMPORTANT: the result values of the QPtrList must be deleted after use. So,
+   * if you don't copy the KAddressInfo objects, the best way to assure that
    * is to call setAutoDelete(true) on the list right after this function
    * returns. If you do copy the results out, you must assure that the objects
    * get deleted when they are not needed any more.
    *
    * @param host	the hostname to look up
    * @param port	the port/service to look up
-   * @param flags	flags to be used when looking up, @ref Flags
+   * @param flags	flags to be used when looking up, Flags
    * @param error	pointer to a variable holding the error code
-   * @return a list of @ref KAddressInfos
+   * @return a list of KAddressInfos
    */
-  static QPtrList<KAddressInfo> lookup(const QString& host, const QString& port, int flags = 0, int *error = 0);
+  static QPtrList<KAddressInfo> lookup(const QString& host, const QString& port, int flags = 0, int *error = 0) KDE_DEPRECATED;
 
   /**
    * Returns the local socket address
@@ -925,7 +974,7 @@ public:
    * @param fd		the file descriptor
    * @return the local socket address or 0 if an error occurred. Delete after use.
    */
-  static KSocketAddress *localAddress(int fd);
+  static ::KSocketAddress *localAddress(int fd) KDE_DEPRECATED;
 
   /**
    * Returns the peer socket address. Use KExtendedSocket::resolve() to
@@ -934,7 +983,7 @@ public:
    * @param fd		the file descriptor
    * @return the peer socket address or 0 if an error occurred. Delete after use.
    */
-  static KSocketAddress *peerAddress(int fd);
+  static ::KSocketAddress *peerAddress(int fd) KDE_DEPRECATED;
 
   /**
    * Returns the representing text of this error code
@@ -953,7 +1002,7 @@ public:
    * @param enable	if true, set address reusable
    * @return true on success, false on failure.
    */
-  static bool setAddressReusable(int fd, bool enable);
+  static bool setAddressReusable(int fd, bool enable) KDE_DEPRECATED;
 
 protected:
   virtual void virtual_hook( int id, void* data );
@@ -964,20 +1013,22 @@ private:
   friend class KServerSocket;
 };
 
-/**
+/** @deprecated
+ * This class is now deprecated. Please see @ref KNetwork::KResolver for the new API.
+ *
  * Contains information about an internet address. It wraps addrinfo,
  * see getaddrinfo(3) for more information.
  */
-class KAddressInfo
+class KDECORE_EXPORT KAddressInfo
 {
 private:
   addrinfo *ai;
-  KSocketAddress *addr;
+  ::KSocketAddress *addr;
 
   inline KAddressInfo() : ai(0), addr(0)
   { }
 
-  KAddressInfo(addrinfo *ai);
+  //  KAddressInfo(addrinfo *ai);
   KAddressInfo(KAddressInfo&) { }
   KAddressInfo& operator=(KAddressInfo&) { return *this; }
 
@@ -985,56 +1036,56 @@ public:
   ~KAddressInfo();
 
   /**
-   * Returns the KAddressInfo's @ref KSocketAddress.
+   * Returns the KAddressInfo's KSocketAddress.
    * Only valid as long as the KAddressInfo exists.
    */
-  inline operator const KSocketAddress*() const
+  inline KDE_DEPRECATED operator const ::KSocketAddress*() const 
   { return addr; }
 
   /**
    * Returns the KAddressInfo's addrinfo.
    */
-  inline operator const addrinfo&() const
+  inline KDE_DEPRECATED operator const addrinfo&() const
   { return *ai; }
 
   /**
-   * Returns a pointer to KAddressInfo's addrinfo. 
+   * Returns a pointer to KAddressInfo's addrinfo.
    * Only valid as long as the KAddressInfo exists.
    */
-  inline operator const addrinfo*() const
+  inline KDE_DEPRECATED operator const addrinfo*() const
   { return ai; }
 
   /**
-   * Returns the KAddressInfo's @ref KSocketAddress.
+   * Returns the KAddressInfo's KSocketAddress.
    * Only valid as long as the KAddressInfo exists.
    * @return the KAddressInfo's KSocketAddress.
    */
-  inline const KSocketAddress* address() const
+  inline KDE_DEPRECATED const ::KSocketAddress* address() const
   { return addr; }
 
   /**
    * Returns the flags of the address info (see getaddrinfo(3)).
    * @return the flags of the addres info.
    */
-  int flags() const;
+  int flags() const KDE_DEPRECATED;
 
   /**
    * Returns the family of the address info (see getaddrinfo(3)).
    * @return the family of the addres info.
    */
-  int family() const;
+  int family() const KDE_DEPRECATED;
 
   /**
    * Returns the socket type of the address info (see getaddrinfo(3)).
    * @return the socket type of the addres info.
    */
-  int socktype() const;
+  int socktype() const KDE_DEPRECATED;
 
   /**
    * Returns the protocol of the address info (see getaddrinfo(3)).
    * @return the protocol of the addres info.
    */
-  int protocol() const;
+  int protocol() const KDE_DEPRECATED;
 
 
   /**
@@ -1042,7 +1093,7 @@ public:
    * Only valid as long as the KAddressInfo exists.
    * @return the official name of the host
    */
-  const char* canonname() const;
+  const char* canonname() const KDE_DEPRECATED;
 
   /**
    * Returns the length of the KSocketAddress.
@@ -1054,4 +1105,6 @@ public:
   friend class KExtendedSocket;
 };
 
+#endif //Q_OS_UNIX
+
 #endif // KEXTSOCK_H
