@@ -54,7 +54,7 @@ struct URLArgsPrivate;
  * This can also be used the other way round, when a part asks
  * for a URL to be opened (with openURLRequest or createNewWindow).
  */
-struct URLArgs
+struct KPARTS_EXPORT URLArgs
 {
   URLArgs();
   URLArgs( const URLArgs &args );
@@ -92,7 +92,7 @@ struct URLArgs
    * KHTML-specific field, contents of the HTTP POST data.
    */
   QByteArray postData;
-  
+
   /**
    * KHTML-specific field, header defining the type of the POST data.
    */
@@ -106,7 +106,7 @@ struct URLArgs
    * for the next openURL.
    */
   void setDoPost( bool enable );
-  
+
   /**
    * KHTML-specific field, whether to do a POST instead of a GET,
    * for the next openURL.
@@ -159,6 +159,18 @@ struct URLArgs
    */
   void setRedirectedRequest(bool redirected);
 
+  /**
+   * Set whether the URL specifies to be opened in a new window
+   * @since 3.4
+   */
+  void setForcesNewWindow( bool forcesNewWindow );
+  
+  /**
+   * Whether the URL specifies to be opened in a new window
+   * @since 3.4
+   */
+  bool forcesNewWindow() const;
+  
   URLArgsPrivate *d;
 };
 
@@ -169,7 +181,7 @@ struct WindowArgsPrivate;
  * call (see the createNewWindow variant that uses WindowArgs).
  * The primary reason for this is the javascript window.open function.
  */
-struct WindowArgs
+struct KPARTS_EXPORT WindowArgs
 {
     WindowArgs();
     WindowArgs( const WindowArgs &args );
@@ -197,7 +209,7 @@ struct WindowArgs
     WindowArgsPrivate *d; // yes, I am paranoid :-)
 };
 
-class OpenURLEvent : public Event
+class KPARTS_EXPORT OpenURLEvent : public Event
 {
 public:
   OpenURLEvent( ReadOnlyPart *part, const KURL &url, const URLArgs &args = URLArgs() );
@@ -256,6 +268,7 @@ class BrowserExtensionPrivate;
   * @li @p shred : Shred selected items (secure deletion) - DEPRECATED.
   * @li @p properties : Show file/document properties.
   * @li @p editMimeType : show file/document's mimetype properties.
+  * @li @p searchProvider : Lookup selected text at default search provider
   *
   * [normal actions]
   * @li @p print : Print :-)
@@ -282,7 +295,7 @@ class BrowserExtensionPrivate;
   * @li @p setSaveViewPropertiesLocally( bool ): If @p true, view properties are saved into .directory
   *                                       otherwise, they are saved globally.
   */
-class BrowserExtension : public QObject
+class KPARTS_EXPORT BrowserExtension : public QObject
 {
   Q_OBJECT
   Q_PROPERTY( bool urlDropHandling READ isURLDropHandlingEnabled WRITE setURLDropHandlingEnabled )
@@ -310,10 +323,19 @@ public:
    * ShowBookmark: show "add to bookmarks" (usually not done on the local filesystem)
    * ShowCreateDirectory: show "create directory" (usually only done on the background of the view, or
    *                      in hierarchical views like directory trees, where the new dir would be visible)
+   * ShowTextSelectionItems: set when selecting text, for a popup that only contains text-related items.
+   * NoDeletion: deletion, trashing and renaming not allowed (e.g. parent dir not writeable).
+   *            (this is only needed if the protocol itself supports deletion, unlike e.g. HTTP)
+   *
+   * KDE4 TODO: add IsLink flag, for "Bookmark This Link" and linkactions merging group.
+   *                    [currently it depends on which signal is emitted]
+   *            add ShowURLOperation flags for copy,cut,paste,rename,trash,del [same thing]
    */
   enum { DefaultPopupItems=0x0000, ShowNavigationItems=0x0001,
          ShowUp=0x0002, ShowReload=0x0004, ShowBookmark=0x0008,
-         ShowCreateDirectory=0x0010 };
+         ShowCreateDirectory=0x0010, ShowTextSelectionItems=0x0020,
+         NoDeletion=0x0040 ///< @since 3.4
+       };
 
 
   /**
@@ -438,7 +460,7 @@ public:
    * Asks the hosting browser to perform a paste.
    * @since 3.2
    */
-  void pasteRequest(); 
+  void pasteRequest();
 // KDE invents support for public signals...
 #undef signals
 #define signals public
@@ -622,6 +644,18 @@ signals:
    */
   void resizeTopLevelWidget( int w, int h );
 
+  /**
+   * Ask the hosting application to focus @p part.
+   * @since 3.4
+   */
+  void requestFocus(KParts::ReadOnlyPart *part);
+
+  /**
+   * Tell the host (browser) about security state of current page
+   * enum PageSecurity { NotCrypted, Encrypted, Mixed };
+   * @since 3.4
+   */
+  void setPageSecurity( int );
 
 private slots:
   void slotCompleted();
@@ -650,7 +684,7 @@ private:
  * other parts.
  * For instance a KHTMLPart hosts one part per frame.
  */
-class BrowserHostExtension : public QObject
+class KPARTS_EXPORT BrowserHostExtension : public QObject
 {
   Q_OBJECT
 public:
@@ -674,9 +708,9 @@ public:
   virtual const QPtrList<KParts::ReadOnlyPart> frames() const;
 
   /**
-   * @internal
    * Returns the part that contains @p frame and that may be accessed
    * by @p callingPart
+   * @since 3.3
    */
   BrowserHostExtension *findFrameParent(KParts::ReadOnlyPart *callingPart, const QString &frame);
 
@@ -705,7 +739,7 @@ protected:
       KParts::ReadOnlyPart *callingPart;
       QString frame;
   };
-                                                    
+
   virtual void virtual_hook( int id, void* data );
 private:
   class BrowserHostExtensionPrivate;
@@ -718,7 +752,7 @@ private:
  * A part can have an object hierarchie by using objid as a reference
  * to an object.
  */
-class LiveConnectExtension : public QObject
+class KPARTS_EXPORT LiveConnectExtension : public QObject
 {
   Q_OBJECT
 public:
